<?php

/*

 Copyright (c) 2002 Oregon State University - Network Engineering
 All rights reserved.

 $Id: view.php,v 1.15 2003/01/25 04:51:49 vollmerk Exp $
 $Source: /a1/cvsroot/maint/modules/class/view.php,v $

 This will live inside of the $user object and will contain
   the last SQL query for the current view ... this allows
   us to carry over search results from visit-to-visit.

 This class works by taking the first part of the SQL statment
   (minus ORDER BY ... ASC|DESC LIMIT BY ...,...) and saving
   it for use on the next visit by $user.

 VERY IMPORTANT: do not access/use $this->sql directly ... this
   is very, very bad as we've had to change all "'"'s into "'s (Kveton ows Vollmer beer)
   to get past the serialization problem w/ PHP and single-quotes.
   Instead, make sure you use $this->get_query() and $this->update_sql($sql)
   when getting/updating this variable.

*/

class View {
	var $sql;
	var $sort_type;
	var $sort_order;
	var $offset;
	var $limit;
	var $frozen;

	// dependent on type of sql query
	var $view_type;

	function View ( $sql = false ) {
		global $conf;

		$this->limit     = $conf['max_list'];
		$this->offset    = 0;
		$this->view_type = 'extended';
		$this->frozen    = false;

		// This is the ugliest thing I've ever coded in my life
		//   I will buy a six-pack of beer for _anybody_, _anywhere_
		//   that can solve this for me.  Basically, you can't serialize
		//   a single-quote "'" which means you can't store sql statements
		//   in a session ... which is what this class is all about.  Of
		//   course I figured that out way, way too far into the dev cycle
		//   on this sucker so I have to do this.  If you don't do this
		//   when session_start is called, the Object blows up all over the
		//   the place and PHP writes a bogus/broken session to the db.
		
		// This can be fixed by replaceing ''s with "'s in all sql statements
		//   Instead of changing our entire program we just modified the replace
		//   In new program use a dbl quote. It serializes perfectly!

		$this->sql       = preg_replace("/\'/", "\"", $sql);
	} // View


	// this is called to setup the variables for the next possible
	//   get_query ... this should be called sometime after the user
	//   has been logged in.
	function initialize($sort_type, $offset = 0) {
		
		// if this object is frozen then we are trying to return
		//   the user to the same view they had before without having
		//   to jump through a bunch of hoops and/or code.
		// We only want it to be frozen for one session so we revert here
		//   as well.
		if ( $this->frozen ) {
			$this->frozen = false;
			return;
		}
		
		// they are clicking on the same sort_type again
		//   so invert the sort
		if ( ($sort_type == $this->sort_type) && ($offset == $this->sort_offset) ) {
			if ( $this->sort_order == 'ASC' ) {
				$this->sort_order = 'DESC';
			}
			else {
				$this->sort_order = 'ASC';
			}
		}
		elseif ($sort_type == $this->sort_type) {
			//same sort different page.. don't do anything!
		} 
		else {
			$this->sort_type = $sort_type;
			$this->sort_order = 'ASC';
		}

		$this->offset = $offset; 
	}


	// Take $sql and append each of the vars to build the query
	function get_query () {
		if ( $this->sql ) {
			$sql = preg_replace("/\|/", "'", $this->sql);
		}

		$sql .= " ORDER BY $this->sort_type";

		if ( $this->sort_order ) {
			$sql .= " $this->sort_order";
		}

		if ( $this->offset && $this->limit ) {
			$sql .= " LIMIT $this->offset,$this->limit";
		}
		elseif ( $this->limit ) {
			$sql .= " LIMIT $this->limit";
		}

		return $sql;
	}

	// freeze the current view object at its current place
	function freeze () {
		$this->frozen = true;
	}

	function get_sql () {
		return preg_replace("/\|/", "'", $this->sql);
	}

	function update_sql ($sql) {
		$this->sql = preg_replace("/\'/", "|", $sql);
	}

	function update_sort_type ($sort_type) {
		$this->sort_type = $sort_type;
	}

	function update_sort_order ($sort_order) {
		$this->sort_order = $sort_order;
	}

	function update_offset ($offset) {
		$this->offset = $offset;
	}

	function update_limit ($limit) {
		$this->limit = $limit;
	}

	function update_view_type ($view_type) {
		$this->view_type = $view_type;
	}
}

?>
